@@ -1,10 +1,4 @@
-#include <R.h>
-#include <Rinternals.h>
-
-#include <stdio.h> 
-
-#include "common.h"
-#include "WSG84-defs.h"
+#include "dists_paired_vec.h"
 
 //' R_haversine_paired_vec
 //' @param x_ Single vector of x-values in [1:n], y-values in [n+(1:n)]
@@ -12,7 +6,10 @@
 //' @noRd
 SEXP R_haversine_paired_vec (SEXP x1_, SEXP y1_, SEXP x2_, SEXP y2_)
 {
-    size_t n = length (x1_);
+    size_t n = (size_t) length (x1_);
+
+    double *rx1, *ry1, *rx2, *ry2, *rout;
+    double cosy1, cosy2;
 
     SEXP out = PROTECT (allocVector (REALSXP, n));
     x1_ = PROTECT (Rf_coerceVector (x1_, REALSXP));
@@ -20,7 +17,6 @@ SEXP R_haversine_paired_vec (SEXP x1_, SEXP y1_, SEXP x2_, SEXP y2_)
     x2_ = PROTECT (Rf_coerceVector (x2_, REALSXP));
     y2_ = PROTECT (Rf_coerceVector (y2_, REALSXP));
 
-    double *rx1, *ry1, *rx2, *ry2, *rout;
     rx1 = REAL (x1_);
     ry1 = REAL (y1_);
     rx2 = REAL (x2_);
@@ -31,8 +27,8 @@ SEXP R_haversine_paired_vec (SEXP x1_, SEXP y1_, SEXP x2_, SEXP y2_)
     {
         if (i % 1000 == 0)
             R_CheckUserInterrupt (); // # nocov
-        double cosy1 = cos (ry1 [i] * M_PI / 180.0); // y-value of x data
-        double cosy2 = cos (ry2 [i] * M_PI / 180.0);
+        cosy1 = cos (ry1 [i] * M_PI / 180.0); // y-value of x data
+        cosy2 = cos (ry2 [i] * M_PI / 180.0);
         rout [i] = one_haversine (rx1 [i], ry1 [i], rx2 [i], ry2 [i],
                 cosy1, cosy2);
     }
@@ -48,7 +44,10 @@ SEXP R_haversine_paired_vec (SEXP x1_, SEXP y1_, SEXP x2_, SEXP y2_)
 //' @noRd
 SEXP R_vincenty_paired_vec (SEXP x1_, SEXP y1_, SEXP x2_, SEXP y2_)
 {
-    size_t n = length (x1_);
+    size_t n = (size_t) length (x1_);
+
+    double *rx1, *ry1, *rx2, *ry2, *rout;
+    double siny1, cosy1, siny2, cosy2;
 
     SEXP out = PROTECT (allocVector (REALSXP, n));
     x1_ = PROTECT (Rf_coerceVector (x1_, REALSXP));
@@ -56,7 +55,6 @@ SEXP R_vincenty_paired_vec (SEXP x1_, SEXP y1_, SEXP x2_, SEXP y2_)
     x2_ = PROTECT (Rf_coerceVector (x2_, REALSXP));
     y2_ = PROTECT (Rf_coerceVector (y2_, REALSXP));
 
-    double *rx1, *ry1, *rx2, *ry2, *rout;
     rx1 = REAL (x1_);
     ry1 = REAL (y1_);
     rx2 = REAL (x2_);
@@ -67,12 +65,12 @@ SEXP R_vincenty_paired_vec (SEXP x1_, SEXP y1_, SEXP x2_, SEXP y2_)
     {
         if (i % 1000 == 0)
             R_CheckUserInterrupt (); // # nocov
-        double siny1 = sin (ry1 [i] * M_PI / 180.0); // y-value of x data
-        double cosy1 = cos (ry1 [i] * M_PI / 180.0); // y-value of x data
-        double siny2 = sin (ry2 [i] * M_PI / 180.0);
-        double cosy2 = cos (ry2 [i] * M_PI / 180.0);
-        rout [i] = one_vincenty (rx1 [i], ry1 [i],
-                rx2 [i], ry2 [i], siny1, cosy1, siny2, cosy2);
+        siny1 = sin (ry1 [i] * M_PI / 180.0); // y-value of x data
+        cosy1 = cos (ry1 [i] * M_PI / 180.0); // y-value of x data
+        siny2 = sin (ry2 [i] * M_PI / 180.0);
+        cosy2 = cos (ry2 [i] * M_PI / 180.0);
+        rout [i] = one_vincenty (rx1 [i], rx2 [i],
+                siny1, cosy1, siny2, cosy2);
     }
 
     UNPROTECT (5);
@@ -85,7 +83,10 @@ SEXP R_vincenty_paired_vec (SEXP x1_, SEXP y1_, SEXP x2_, SEXP y2_)
 //' @noRd
 SEXP R_cheap_paired_vec (SEXP x1_, SEXP y1_, SEXP x2_, SEXP y2_)
 {
-    size_t n = length (x1_);
+    size_t n = (size_t) length (x1_);
+    double *rx1, *ry1, *rx2, *ry2, *rout;
+    double ymin = 9999.9, ymax = -9999.9;
+    double cosy;
 
     SEXP out = PROTECT (allocVector (REALSXP, n));
     x1_ = PROTECT (Rf_coerceVector (x1_, REALSXP));
@@ -93,7 +94,6 @@ SEXP R_cheap_paired_vec (SEXP x1_, SEXP y1_, SEXP x2_, SEXP y2_)
     x2_ = PROTECT (Rf_coerceVector (x2_, REALSXP));
     y2_ = PROTECT (Rf_coerceVector (y2_, REALSXP));
 
-    double *rx1, *ry1, *rx2, *ry2, *rout;
     rx1 = REAL (x1_);
     ry1 = REAL (y1_);
     rx2 = REAL (x2_);
@@ -101,7 +101,6 @@ SEXP R_cheap_paired_vec (SEXP x1_, SEXP y1_, SEXP x2_, SEXP y2_)
     rout = REAL (out);
 
     // Get maximal latitude range
-    double ymin = 9999.9, ymax = -9999.9;
     for (size_t i = 0; i < n; i++)
     {
         if (ry1 [i] < ymin)
@@ -116,7 +115,7 @@ SEXP R_cheap_paired_vec (SEXP x1_, SEXP y1_, SEXP x2_, SEXP y2_)
     // and set constant cosine multiplier
     ymin = ymin * M_PI / 180;
     ymax = ymax * M_PI / 180;
-    double cosy = cos ((ymin + ymax) / 2.0);
+    cosy = cos ((ymin + ymax) / 2.0);
 
     for (size_t i = 0; i < n; i++)
     {
@@ -137,7 +136,8 @@ SEXP R_cheap_paired_vec (SEXP x1_, SEXP y1_, SEXP x2_, SEXP y2_)
 //' @noRd
 SEXP R_geodesic_paired_vec (SEXP x1_, SEXP y1_, SEXP x2_, SEXP y2_)
 {
-    size_t n = length (x1_);
+    size_t n = (size_t) length (x1_);
+    double *rx1, *ry1, *rx2, *ry2, *rout;
 
     SEXP out = PROTECT (allocVector (REALSXP, n));
     x1_ = PROTECT (Rf_coerceVector (x1_, REALSXP));
@@ -145,7 +145,6 @@ SEXP R_geodesic_paired_vec (SEXP x1_, SEXP y1_, SEXP x2_, SEXP y2_)
     x2_ = PROTECT (Rf_coerceVector (x2_, REALSXP));
     y2_ = PROTECT (Rf_coerceVector (y2_, REALSXP));
 
-    double *rx1, *ry1, *rx2, *ry2, *rout;
     rx1 = REAL (x1_);
     ry1 = REAL (y1_);
     rx2 = REAL (x2_);
