@@ -1,10 +1,4 @@
-#include <R.h>
-#include <Rinternals.h>
-
-#include <stdio.h> 
-
-#include "common.h"
-#include "WSG84-defs.h"
+#include "dists_x_vec.h"
 
 //' R_haversine
 //' @param x_ Single vector of x-values
@@ -12,20 +6,21 @@
 //' @noRd
 SEXP R_haversine_vec (SEXP x_, SEXP y_)
 {
-    size_t n = length (x_);
-    size_t n2 = n * n;
+    size_t n = (size_t) length (x_);
     //Rprintf ("n = %d ; len = %d \n", n, n2);
+    size_t n2 = n * n;
+
+    double cosy1 [n]; // y-values are indexed in [n+1:n]
+    double *rx, *ry, *rout;
 
     SEXP out = PROTECT (allocVector (REALSXP, n2));
     x_ = PROTECT (Rf_coerceVector (x_, REALSXP));
     y_ = PROTECT (Rf_coerceVector (y_, REALSXP));
 
-    double *rx, *ry, *rout;
     rx = REAL (x_);
     ry = REAL (y_);
     rout = REAL (out);
 
-    double cosy1 [n]; // y-values are indexed in [n+1:n]
     for (size_t i = 0; i < n; i++)
     {
         cosy1 [i] = cos (ry [i] * M_PI / 180.0);
@@ -56,19 +51,20 @@ SEXP R_haversine_vec (SEXP x_, SEXP y_)
 //' @noRd
 SEXP R_vincenty_vec (SEXP x_, SEXP y_)
 {
-    size_t n = length (x_);
+    size_t n = (size_t) length (x_);
     size_t n2 = n * n;
+    double *rx, *ry, *rout;
+    double siny1 [n], cosy1 [n]; // y-values are indexed in [n+1:n]
+    size_t indx1, indx2;
 
     SEXP out = PROTECT (allocVector (REALSXP, n2));
     x_ = PROTECT (Rf_coerceVector (x_, REALSXP));
     y_ = PROTECT (Rf_coerceVector (y_, REALSXP));
 
-    double *rx, *ry, *rout;
     rx = REAL (x_);
     ry = REAL (y_);
     rout = REAL (out);
 
-    double siny1 [n], cosy1 [n]; // y-values are indexed in [n+1:n]
     for (size_t i = 0; i < n; i++)
     {
         cosy1 [i] = cos (ry [i] * M_PI / 180.0);
@@ -82,10 +78,9 @@ SEXP R_vincenty_vec (SEXP x_, SEXP y_)
             R_CheckUserInterrupt (); // # nocov
         for (size_t j = (i + 1); j < n; j++)
         {
-            size_t indx1 = i * n + j;
-            size_t indx2 = j * n + i;
-            rout [indx1] = rout [indx2] = one_vincenty (rx [i], ry [i],
-                    rx [j], ry [j],
+            indx1 = i * n + j;
+            indx2 = j * n + i;
+            rout [indx1] = rout [indx2] = one_vincenty (rx [i], rx [j],
                     siny1 [i], cosy1 [i], siny1 [j], cosy1 [j]);
         }
     }
@@ -101,20 +96,22 @@ SEXP R_vincenty_vec (SEXP x_, SEXP y_)
 //' @noRd
 SEXP R_cheap_vec (SEXP x_, SEXP y_)
 {
-    size_t n = length (x_);
+    size_t n = (size_t) length (x_);
     size_t n2 = n * n;
+    double *rx, *ry, *rout;
+    double ymin = 9999.9, ymax = -9999.9;
+    double cosy;
+    size_t indx1, indx2;
 
     SEXP out = PROTECT (allocVector (REALSXP, n2));
     x_ = PROTECT (Rf_coerceVector (x_, REALSXP));
     y_ = PROTECT (Rf_coerceVector (y_, REALSXP));
 
-    double *rx, *ry, *rout;
     rx = REAL (x_);
     ry = REAL (y_);
     rout = REAL (out);
 
     // Get maximal latitude range
-    double ymin = 9999.9, ymax = -9999.9;
     for (size_t i = 0; i < n; i++)
     {
         if (ry [i] < ymin)
@@ -126,7 +123,7 @@ SEXP R_cheap_vec (SEXP x_, SEXP y_)
     // and set constant cosine multiplier
     ymin = ymin * M_PI / 180;
     ymax = ymax * M_PI / 180;
-    double cosy = cos ((ymin + ymax) / 2.0);
+    cosy = cos ((ymin + ymax) / 2.0);
 
     for (size_t i = 0; i < (n - 1); i++)
     {
@@ -134,8 +131,8 @@ SEXP R_cheap_vec (SEXP x_, SEXP y_)
             R_CheckUserInterrupt (); // # nocov
         for (size_t j = (i + 1); j < n; j++)
         {
-            size_t indx1 = i * n + j;
-            size_t indx2 = j * n + i;
+            indx1 = i * n + j;
+            indx2 = j * n + i;
             rout [indx1] = rout [indx2] = one_cheap (rx [i], ry [i],
                     rx [j], ry [j], cosy);
         }
@@ -152,14 +149,15 @@ SEXP R_cheap_vec (SEXP x_, SEXP y_)
 //' @noRd
 SEXP R_geodesic_vec (SEXP x_, SEXP y_)
 {
-    size_t n = length (x_);
+    size_t n = (size_t) length (x_);
     size_t n2 = n * n;
+    double *rx, *ry, *rout;
+    size_t indx1, indx2;
 
     SEXP out = PROTECT (allocVector (REALSXP, n2));
     x_ = PROTECT (Rf_coerceVector (x_, REALSXP));
     y_ = PROTECT (Rf_coerceVector (y_, REALSXP));
 
-    double *rx, *ry, *rout;
     rx = REAL (x_);
     ry = REAL (y_);
     rout = REAL (out);
@@ -173,8 +171,8 @@ SEXP R_geodesic_vec (SEXP x_, SEXP y_)
             R_CheckUserInterrupt (); // # nocov
         for (size_t j = (i + 1); j < n; j++)
         {
-            size_t indx1 = i * n + j;
-            size_t indx2 = j * n + i;
+            indx1 = i * n + j;
+            indx2 = j * n + i;
             rout [indx1] = rout [indx2] = one_geodesic (rx [i], ry [i],
                     rx [j], ry [j]);
         }
